==> kcoreaddons-5.68.0.tgz: include/KF5/KCoreAddons/kcoreaddons_export.h <==

#ifndef KCOREADDONS_EXPORT_H
#define KCOREADDONS_EXPORT_H

#ifdef KCOREADDONS_STATIC_DEFINE
#  define KCOREADDONS_EXPORT
#  define KCOREADDONS_NO_EXPORT
#else
#  ifndef KCOREADDONS_EXPORT
#    ifdef KF5CoreAddons_EXPORTS
        /* We are building this library */
#      define KCOREADDONS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KCOREADDONS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KCOREADDONS_NO_EXPORT
#    define KCOREADDONS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KCOREADDONS_DECL_DEPRECATED
#  define KCOREADDONS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCOREADDONS_DECL_DEPRECATED_EXPORT
#  define KCOREADDONS_DECL_DEPRECATED_EXPORT KCOREADDONS_EXPORT KCOREADDONS_DECL_DEPRECATED
#endif

#ifndef KCOREADDONS_DECL_DEPRECATED_NO_EXPORT
#  define KCOREADDONS_DECL_DEPRECATED_NO_EXPORT KCOREADDONS_NO_EXPORT KCOREADDONS_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCOREADDONS_NO_DEPRECATED
#    define KCOREADDONS_NO_DEPRECATED
#  endif
#endif

#define KCOREADDONS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCOREADDONS_NO_DEPRECATED) && !defined(KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCOREADDONS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCOREADDONS_NO_DEPRECATED_WARNINGS) && !defined(KCOREADDONS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCOREADDONS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCOREADDONS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCOREADDONS_NO_DEPRECATED)
#  undef KCOREADDONS_DEPRECATED
#  define KCOREADDONS_DEPRECATED_EXPORT KCOREADDONS_EXPORT
#  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_NO_EXPORT
#elif defined(KCOREADDONS_NO_DEPRECATED_WARNINGS)
#  define KCOREADDONS_DEPRECATED
#  define KCOREADDONS_DEPRECATED_EXPORT KCOREADDONS_EXPORT
#  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_NO_EXPORT
#else
#  define KCOREADDONS_DEPRECATED KCOREADDONS_DECL_DEPRECATED
#  define KCOREADDONS_DEPRECATED_EXPORT KCOREADDONS_DECL_DEPRECATED_EXPORT
#  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCOREADDONS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCOREADDONS_NO_DEPRECATED
#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54400
#endif
#ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
#  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCOREADDONS_DEPRECATED_WARNINGS_SINCE
#  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x54400
#  endif
#endif

#ifndef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCOREADDONS_DEPRECATED
#  define KCOREADDONS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCOREADDONS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KCOREADDONS_DEPRECATED_VERSION_4_0(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_4_0(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KCOREADDONS_DEPRECATED_VERSION_5_0(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_0(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x50200
#  define KCOREADDONS_DEPRECATED_VERSION_5_2(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_2(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54100
#  define KCOREADDONS_DEPRECATED_VERSION_5_65(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_65(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54300
#  define KCOREADDONS_DEPRECATED_VERSION_5_67(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_67(text)
#endif
#define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
#define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
#define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)

#endif /* KCOREADDONS_EXPORT_H */

==> kcoreaddons-5.85.0.tgz: include/KF5/KCoreAddons/kcoreaddons_export.h <==

#ifndef KCOREADDONS_EXPORT_H
#define KCOREADDONS_EXPORT_H

#ifdef KCOREADDONS_STATIC_DEFINE
#  define KCOREADDONS_EXPORT
#  define KCOREADDONS_NO_EXPORT
#else
#  ifndef KCOREADDONS_EXPORT
#    ifdef KF5CoreAddons_EXPORTS
        /* We are building this library */
#      define KCOREADDONS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KCOREADDONS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KCOREADDONS_NO_EXPORT
#    define KCOREADDONS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KCOREADDONS_DECL_DEPRECATED
#  define KCOREADDONS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KCOREADDONS_DECL_DEPRECATED_EXPORT
#  define KCOREADDONS_DECL_DEPRECATED_EXPORT KCOREADDONS_EXPORT KCOREADDONS_DECL_DEPRECATED
#endif

#ifndef KCOREADDONS_DECL_DEPRECATED_NO_EXPORT
#  define KCOREADDONS_DECL_DEPRECATED_NO_EXPORT KCOREADDONS_NO_EXPORT KCOREADDONS_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KCOREADDONS_NO_DEPRECATED
#    define KCOREADDONS_NO_DEPRECATED
#  endif
#endif

#define KCOREADDONS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCOREADDONS_NO_DEPRECATED) && !defined(KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCOREADDONS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCOREADDONS_NO_DEPRECATED_WARNINGS) && !defined(KCOREADDONS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCOREADDONS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCOREADDONS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCOREADDONS_NO_DEPRECATED)
#  undef KCOREADDONS_DEPRECATED
#  define KCOREADDONS_DEPRECATED_EXPORT KCOREADDONS_EXPORT
#  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_NO_EXPORT
#elif defined(KCOREADDONS_NO_DEPRECATED_WARNINGS)
#  define KCOREADDONS_DEPRECATED
#  define KCOREADDONS_DEPRECATED_EXPORT KCOREADDONS_EXPORT
#  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_NO_EXPORT
#else
#  define KCOREADDONS_DEPRECATED KCOREADDONS_DECL_DEPRECATED
#  define KCOREADDONS_DEPRECATED_EXPORT KCOREADDONS_DECL_DEPRECATED_EXPORT
#  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCOREADDONS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCOREADDONS_NO_DEPRECATED
#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
#endif
#ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
#  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCOREADDONS_DEPRECATED_WARNINGS_SINCE
#  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55500
#  endif
#endif

#ifndef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCOREADDONS_DEPRECATED
#  define KCOREADDONS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCOREADDONS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KCOREADDONS_DEPRECATED_VERSION_4_0(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_4_0(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KCOREADDONS_DEPRECATED_VERSION_5_0(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_0(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x50200
#  define KCOREADDONS_DEPRECATED_VERSION_5_2(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_2(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54100
#  define KCOREADDONS_DEPRECATED_VERSION_5_65(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_65(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54300
#  define KCOREADDONS_DEPRECATED_VERSION_5_67(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_67(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54600
#  define KCOREADDONS_DEPRECATED_VERSION_5_70(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_70(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54800
#  define KCOREADDONS_DEPRECATED_VERSION_5_72(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_72(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54b00
#  define KCOREADDONS_DEPRECATED_VERSION_5_75(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_75(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54c00
#  define KCOREADDONS_DEPRECATED_VERSION_5_76(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_76(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54e00
#  define KCOREADDONS_DEPRECATED_VERSION_5_78(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_78(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54f00
#  define KCOREADDONS_DEPRECATED_VERSION_5_79(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_79(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55000
#  define KCOREADDONS_DEPRECATED_VERSION_5_80(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_80(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55400
#  define KCOREADDONS_DEPRECATED_VERSION_5_84(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_84(text)
#endif
#define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
#define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
#define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KCOREADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KCOREADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION(major, minor, text)
#  define KCOREADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOREADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KCOREADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KCOREADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KCOREADDONS_EXPORT_H */


#ifndef ECM_GENERATEEXPORTHEADER_KCOREADDONS_EXPORT_H
#define ECM_GENERATEEXPORTHEADER_KCOREADDONS_EXPORT_H


#define KCOREADDONS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KCOREADDONS_NO_DEPRECATED) && !defined(KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KCOREADDONS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KCOREADDONS_NO_DEPRECATED_WARNINGS) && !defined(KCOREADDONS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KCOREADDONS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KCOREADDONS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KCOREADDONS_NO_DEPRECATED)
#  undef KCOREADDONS_DEPRECATED
#  define KCOREADDONS_DEPRECATED_EXPORT KCOREADDONS_EXPORT
#  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_NO_EXPORT
#elif defined(KCOREADDONS_NO_DEPRECATED_WARNINGS)
#  define KCOREADDONS_DEPRECATED
#  define KCOREADDONS_DEPRECATED_EXPORT KCOREADDONS_EXPORT
#  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_NO_EXPORT
#else
#  define KCOREADDONS_DEPRECATED KCOREADDONS_DECL_DEPRECATED
#  define KCOREADDONS_DEPRECATED_EXPORT KCOREADDONS_DECL_DEPRECATED_EXPORT
#  define KCOREADDONS_DEPRECATED_NO_EXPORT KCOREADDONS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KCOREADDONS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KCOREADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KCOREADDONS_NO_DEPRECATED
#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55500
#endif
#ifdef KCOREADDONS_NO_DEPRECATED_WARNINGS
#  define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KCOREADDONS_DEPRECATED_WARNINGS_SINCE
#  ifdef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KCOREADDONS_DEPRECATED_WARNINGS_SINCE 0x55500
#  endif
#endif

#ifndef KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KCOREADDONS_DEPRECATED
#  define KCOREADDONS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KCOREADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KCOREADDONS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x40000
#  define KCOREADDONS_DEPRECATED_VERSION_4_0(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_4_0(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KCOREADDONS_DEPRECATED_VERSION_5_0(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_0(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x50200
#  define KCOREADDONS_DEPRECATED_VERSION_5_2(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_2(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54100
#  define KCOREADDONS_DEPRECATED_VERSION_5_65(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_65(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54300
#  define KCOREADDONS_DEPRECATED_VERSION_5_67(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_67(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54600
#  define KCOREADDONS_DEPRECATED_VERSION_5_70(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_70(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54800
#  define KCOREADDONS_DEPRECATED_VERSION_5_72(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_72(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54b00
#  define KCOREADDONS_DEPRECATED_VERSION_5_75(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_75(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54c00
#  define KCOREADDONS_DEPRECATED_VERSION_5_76(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_76(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54e00
#  define KCOREADDONS_DEPRECATED_VERSION_5_78(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_78(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x54f00
#  define KCOREADDONS_DEPRECATED_VERSION_5_79(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_79(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55000
#  define KCOREADDONS_DEPRECATED_VERSION_5_80(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_80(text)
#endif

#if KCOREADDONS_DEPRECATED_WARNINGS_SINCE >= 0x55400
#  define KCOREADDONS_DEPRECATED_VERSION_5_84(text) KCOREADDONS_DECL_DEPRECATED_TEXT(text)
#else
#  define KCOREADDONS_DEPRECATED_VERSION_5_84(text)
#endif
#define KCOREADDONS_DEPRECATED_VERSION_4(minor, text)      KCOREADDONS_DEPRECATED_VERSION_4_##minor(text)
#define KCOREADDONS_DEPRECATED_VERSION_5(minor, text)      KCOREADDONS_DEPRECATED_VERSION_5_##minor(text)
#define KCOREADDONS_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KCOREADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOREADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KCOREADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KCOREADDONS_DEPRECATED_VERSION(major, minor, text)
#  define KCOREADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOREADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KCOREADDONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KCOREADDONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif


#endif /* ECM_GENERATEEXPORTHEADER_KCOREADDONS_EXPORT_H */
